@@ -54,6 +54,16 @@ void chum_set_duetto(gboolean b){
 	duetto=b;
 }
 
+
+//FALSE means advanced_game
+static gboolean chum_easy_game = TRUE;
+gboolean chum_is_easy_game(){
+  return chum_easy_game;
+}
+
+void chum_set_easy_game(gboolean b){
+	chum_easy_game=b;
+}
 //This helps logging/debugging state switching
 char *name_of_states[] ={ "SCREEN_WELCOME",
                           "SCREEN_PASSWORD_TYPING",
@@ -303,6 +313,11 @@ JammoEditingTrack* chum_create_new_empty_track() {
 
 	return track;
 }
+
+void chum_make_sequencer(){
+sequencer = jammo_sequencer_new();
+}
+
 void chum_change_theme(int theme_number){
 	JammoSample* sample;
 	
