@@ -1,4 +1,3 @@
-#ifdef OLD_TANGLE_IN_REPOSITORY
 /*
  * jammo-mentor.c
  *
@@ -12,19 +11,21 @@
 #include "jammo-mentor.h"
 #include "../meam/jammo-sample.h"
 
-G_DEFINE_TYPE(JammoMentor, jammo_mentor, CLUTTER_ACTOR);
+G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON);
 
 enum {
 	PROP_0,
 	PROP_STANDBY_SCALE,
+	PROP_ACTIVE_SCALE,
 	PROP_IDLE_SPEECH,
 	PROP_IDLE_TIMEOUT
 };
 
 struct _JammoMentorPrivate {
 	gfloat standby_scale;
+	gfloat active_scale;
 	gchar* idle_speech;
-	guint idle_timeout;
+	gulong idle_timeout;
 	
 	GList* spoken_speeches;
 	guint idle_timeout_id;
@@ -37,9 +38,9 @@ static void set_idle_timeout(JammoMentor* mentor, gboolean activate);
 
 static GList* mentors;
 
-JammoMentor* jammo_mentor_new(ClutterActor* actor, gfloat standby_scale) {
+ClutterActor* jammo_mentor_new(ClutterActor* actor, gfloat standby_scale, gfloat active_scale) {
 
-	return JAMMO_MENTOR(g_object_new(JAMMO_TYPE_MENTOR, "normal-background-actor", actor, "standby-scale", standby_scale, "prefer-background-size", TRUE, NULL));
+	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_MENTOR, "normal-background-actor", actor, "standby-scale", standby_scale, "active-scale", active_scale, "prefer-background-size", TRUE, NULL));
 }
 
 gfloat jammo_mentor_get_standby_scale(JammoMentor* mentor) {
@@ -51,12 +52,27 @@ void jammo_mentor_set_standby_scale(JammoMentor* mentor, gfloat scale) {
 	if (mentor->priv->standby_scale != scale) {
 		mentor->priv->standby_scale = scale;
 		if (!mentor->priv->active_sample) {
-			clutter_actor_set_scale(CLUTTER_ACTOR(mentor), scale, scale);
+			tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
 		}
 		g_object_notify(G_OBJECT(mentor), "standby-scale");
 	}
 }
 
+gfloat jammo_mentor_get_active_scale(JammoMentor* mentor) {
+
+	return mentor->priv->active_scale;
+}
+
+void jammo_mentor_set_active_scale(JammoMentor* mentor, gfloat scale) {
+	if (mentor->priv->active_scale != scale) {
+		mentor->priv->active_scale = scale;
+		if (mentor->priv->active_sample) {
+			tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
+		}
+		g_object_notify(G_OBJECT(mentor), "active-scale");
+	}
+}
+
 void jammo_mentor_speak(JammoMentor* mentor, const gchar* speech) {
 	speak(mentor, speech, NULL, NULL);
 }
@@ -66,14 +82,14 @@ void jammo_mentor_speak_with_callback(JammoMentor* mentor, const gchar* speech,
 }
 
 void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
-	if (!g_list_find(mentor->priv->spoken_speeches, speech)) {
+	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, NULL, NULL);
 	}
 }
 
 void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
-	if (!g_list_find(mentor->priv->spoken_speeches, speech)) {
+	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, callback, user_data);
 	}
@@ -92,12 +108,12 @@ void jammo_mentor_set_idle_speech(JammoMentor* mentor, const gchar* speech) {
 	}
 }
 
-guint jammo_mentor_get_idle_timeout(JammoMentor* mentor) {
+gulong jammo_mentor_get_idle_timeout(JammoMentor* mentor) {
 
 	return mentor->priv->idle_timeout;
 }
 
-void jammo_mentor_set_idle_timeout(JammoMentor* mentor, guint milliseconds) {
+void jammo_mentor_set_idle_timeout(JammoMentor* mentor, gulong milliseconds) {
 	if (mentor->priv->idle_timeout != milliseconds) {
 		mentor->priv->idle_timeout = milliseconds;
 		if (!mentor->priv->active_sample) {
@@ -112,6 +128,20 @@ JammoMentor* jammo_mentor_get_default(void) {
 	return (mentors ? JAMMO_MENTOR(mentors->data) : NULL);
 }
 
+static gboolean jammo_mentor_clicked(TangleButton* button) {
+	JammoMentor* mentor;
+	
+	mentor = JAMMO_MENTOR(button);
+	
+	if (mentor->priv->active_sample) {
+		jammo_sample_stop(mentor->priv->active_sample);
+	} else if (mentor->priv->idle_speech) {
+		speak(mentor, mentor->priv->idle_speech, NULL, NULL);
+	}
+
+	return FALSE;
+}
+
 static void jammo_mentor_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoMentor* mentor;
 	
@@ -121,11 +151,14 @@ static void jammo_mentor_set_property(GObject* object, guint prop_id, const GVal
 		case PROP_STANDBY_SCALE:
 			jammo_mentor_set_standby_scale(mentor, g_value_get_float(value));
 			break;
+		case PROP_ACTIVE_SCALE:
+			jammo_mentor_set_active_scale(mentor, g_value_get_float(value));
+			break;
 		case PROP_IDLE_SPEECH:
 			jammo_mentor_set_idle_speech(mentor, g_value_get_string(value));
 			break;
 		case PROP_IDLE_TIMEOUT:
-			jammo_mentor_set_idle_timeout(mentor, g_value_get_uint(value));
+			jammo_mentor_set_idle_timeout(mentor, g_value_get_ulong(value));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -142,11 +175,14 @@ static void jammo_mentor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_STANDBY_SCALE:
 			g_value_set_float(value, mentor->priv->standby_scale);
 			break;
+		case PROP_ACTIVE_SCALE:
+			g_value_set_float(value, mentor->priv->active_scale);
+			break;
 		case PROP_IDLE_SPEECH:
 			g_value_set_string(value, mentor->priv->idle_speech);
 			break;
 		case PROP_IDLE_TIMEOUT:
-			g_value_set_uint(value, mentor->priv->idle_timeout);
+			g_value_set_ulong(value, mentor->priv->idle_timeout);
 			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -171,13 +207,61 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	gobject_class->set_property = jammo_mentor_set_property;
 	gobject_class->get_property = jammo_mentor_get_property;
 
-//	button_class->clicked = jammo_mentor_clicked;
+	button_class->clicked = jammo_mentor_clicked;
+
+	/**
+	 * JammoMentor:standby-scale:
+	 *
+	 * The scaling that is efective when the mentor is in standby.
+	 */
+	g_object_class_install_property(gobject_class, PROP_STANDBY_SCALE,
+	                                g_param_spec_float("standby-scale",
+	                                                   "Standby scale",
+	                                                   "The scaling that is efective when the mentor is in standby",
+	                                                   0.0, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:active-scale:
+	 *
+	 * The scaling that is efective when the mentor is active.
+	 */
+	g_object_class_install_property(gobject_class, PROP_ACTIVE_SCALE,
+	                                g_param_spec_float("active-scale",
+	                                                   "Active scale",
+	                                                   "The scaling that is efective when the mentor is active",
+	                                                   0.0, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:idle-speech:
+	 *
+	 * The speech that the mentor will speak after a specified time (see :idle-time).
+	 */
+	g_object_class_install_property(gobject_class, PROP_IDLE_SPEECH,
+	                                g_param_spec_string("idle-speech",
+	                                                    "Idle speech",
+	                                                    "The speech that the mentor will speak after a specified time",
+	                                                    NULL,
+	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:idle-time:
+	 *
+	 * The time after the mentor will speak (see :idle-speech) if an user has been idle.
+	 * Value 0 means disabled.
+	 */
+	g_object_class_install_property(gobject_class, PROP_IDLE_TIMEOUT,
+	                                g_param_spec_ulong("idle-timeout",
+	                                                   "Idle timeout",
+	                                                   "The time after the mentor will speak if an user has been idle.",
+	                                                   0, G_MAXULONG, 0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
 
 	g_type_class_add_private (gobject_class, sizeof (JammoMentorPrivate));
 }
 
 static void jammo_mentor_init(JammoMentor* mentor) {
 	mentor->priv = G_TYPE_INSTANCE_GET_PRIVATE(mentor, JAMMO_TYPE_MENTOR, JammoMentorPrivate);
+
+	mentors = g_list_append(mentors, mentor);
 }
 
 static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
@@ -192,8 +276,12 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	
 	g_object_unref(mentor->priv->active_sample);
 	mentor->priv->active_sample = NULL;
+
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
 	
-	callback(mentor, speech, data);
+	if (callback) {
+		callback(mentor, speech, data);
+	}
 }
 
 static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
@@ -214,10 +302,11 @@ static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCal
 	vault = tangle_vault_new(4, JAMMO_TYPE_MENTOR, mentor, G_TYPE_POINTER, callback, G_TYPE_STRING, speech, G_TYPE_POINTER, user_data);
 	tangle_signal_connect_vault(mentor->priv->active_sample, "stopped", G_CALLBACK(on_sample_stopped), vault);
 	
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
+	
 	jammo_sample_play(mentor->priv->active_sample);
 }
 
 static void set_idle_timeout(JammoMentor* mentor, gboolean activate) {
-	/* TOFO */
+	/* TODO */
 }
-#endif
