@@ -11,4 +11,7 @@ void start_mobikid_recording();
 void start_mobikid_play_recorded();
 void start_mobikid_selection();
 
+void init_singing_game();
+gboolean singing_game_is_initialized();
+
 #endif /* SINGING_GAME_H */
