@@ -62,14 +62,21 @@ void gui_visualize_playing(void) {
 }
 
 static void show_welcome() {
+	gchar* filename;
+	JammoSample* sample;
+	
     printf("Welcome to JamMo, press any key to continue (open door).\n");
     mygetch(); 
-    chum_play_one_sample(g_strdup_printf("%s/door_opening.wav",DATA_DIR));
+    filename = g_strdup_printf("%s/door_opening.wav",DATA_DIR);
+    sample = jammo_sample_new_from_file(filename);
+    g_free(filename);
+    jammo_sample_play(sample);
     printf("Door opening...\n");
     printf("(you can skip by pressing any key)\n");
     printf("(you must press any key to continue)\n");
     mygetch();
-    chum_stop_one_sample();
+    jammo_sample_stop(sample);
+    g_object_unref(sample);
     chum_go_next();
 }
 
@@ -386,7 +393,10 @@ static void *start_theme() {
 
 	  buffer0 = g_strdup_printf("%s/%s/%s",THEMES_DIR,chum_get_theme_folder(chum_get_current_theme()), selected_sound);
 
-	  chum_play_one_sample(buffer0);
+	  JammoSample* sample = jammo_sample_new_from_file(buffer0);
+	  g_free(buffer0);
+	  jammo_sample_play(sample);
+	  g_object_unref(sample);
 	  break;
 
 	default:
